==> nhc98src-1.18.tar.gz: nhc98-1.18/src/prelude/PreludeList/Span.z.c <==
#include "newmacros.h"
#include "runtime.h"

#define v193	((void*)startLabel+26)
#define v194	((void*)startLabel+37)
#define v195	((void*)startLabel+76)
#define v197	((void*)startLabel+93)
#define v190	((void*)startLabel+98)
#define CT_v201	((void*)startLabel+136)
#define FN_LAMBDA188	((void*)startLabel+180)
#define CT_v204	((void*)startLabel+212)
#define CF_LAMBDA188	((void*)startLabel+220)
#define FN_LAMBDA187	((void*)startLabel+232)
#define CT_v206	((void*)startLabel+256)
#define F0_LAMBDA187	((void*)startLabel+264)
#define FN_LAMBDA186	((void*)startLabel+276)
#define CT_v208	((void*)startLabel+300)
#define F0_LAMBDA186	((void*)startLabel+308)
#define ST_v199	((void*)startLabel+312)
#define ST_v202	((void*)startLabel+325)
#define ST_v207	((void*)startLabel+347)
#define ST_v205	((void*)startLabel+370)
#define ST_v203	((void*)startLabel+393)
extern Node TM_Prelude[];
extern Node CF_Prelude_46otherwise[];
extern Node FN_Prelude_46error[];
extern Node TMSUB_Prelude[];

static Node startLabel[] = {
  bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v201)
,};
Node FN_Prelude_46span[] = {
  useLabel(TM_Prelude)
, bytes2word(NEEDSTACK_I16,PUSH_ARG_I2,EVAL,NEEDHEAP_I32)
, bytes2word(TABLESWITCH,2,TOP(4),BOT(4))
,	/* v193: (byte 2) */
  bytes2word(TOP(15),BOT(15),POP_I1,HEAP_CVAL_IN3)
, bytes2word(HEAP_CVAL_IN3,PUSH_HEAP,HEAP_CVAL_N1,4)
, bytes2word(HEAP_OFF_N1,3,HEAP_OFF_N1,3)
,	/* v194: (byte 1) */
  bytes2word(RETURN,UNPACK,2,PUSH_P1)
, bytes2word(0,PUSH_ARG_I1,EVAL,NEEDHEAP_I32)
, bytes2word(APPLY,1,EVAL,NEEDHEAP_I32)
, bytes2word(JUMPFALSE,27,0,PUSH_HEAP)
, bytes2word(HEAP_CVAL_I3,HEAP_ARG,1,HEAP_I2)
, bytes2word(PUSH_HEAP,HEAP_CVAL_I4,HEAP_OFF_N1,4)
, bytes2word(PUSH_HEAP,HEAP_CVAL_I5,HEAP_OFF_N1,6)
, bytes2word(HEAP_CVAL_N1,5,HEAP_P1,3)
, bytes2word(HEAP_I1,PUSH_HEAP,HEAP_CVAL_N1,4)
,	/* v195: (byte 4) */
  bytes2word(HEAP_OFF_N1,4,HEAP_I1,RETURN)
, bytes2word(PUSH_CVAL_P1,6,ZAP_ARG_I1,EVAL)
, bytes2word(NEEDHEAP_I32,JUMPFALSE,11,0)
, bytes2word(HEAP_CVAL_IN3,PUSH_HEAP,HEAP_CVAL_N1,4)
, bytes2word(HEAP_OFF_N1,2,HEAP_ARG,2)
,	/* v197: (byte 1) */
  bytes2word(RETURN,POP_P1,2,JUMP)
,	/* v190: (byte 2) */
  bytes2word(2,0,HEAP_CVAL_P1,7)
, bytes2word(PUSH_HEAP,HEAP_CVAL_P1,8,HEAP_OFF_N1)
, bytes2word(2,RETURN_EVAL,ENDCODE,0)
, bytes2word(0,0,0,0)
, 0
, CONSTR(1,2,0)
, CONSTR(0,2,0)
, CONSTR(0,0,0)
, 40001
, useLabel(ST_v199)
,	/* CT_v201: (byte 0) */
  HW(6,2)
, 0
,};
Node F0_Prelude_46span[] = {
  CAPTAG(useLabel(FN_Prelude_46span),2)
, VAPTAG(useLabel(FN_Prelude_46span))
, VAPTAG(useLabel(FN_LAMBDA186))
, VAPTAG(useLabel(FN_LAMBDA187))
, useLabel(CF_Prelude_46otherwise)
, VAPTAG(useLabel(FN_LAMBDA188))
, VAPTAG(useLabel(FN_Prelude_46error))
, bytes2word(0,0,0,0)
, useLabel(CT_v204)
,	/* FN_LAMBDA188: (byte 0) */
  useLabel(TMSUB_Prelude)
, bytes2word(NEEDHEAP_I32,PUSH_CADR_N1,4,STRING)
, bytes2word(RETURN,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, CONSTRW(1,0)
, useLabel(ST_v203)
, 40001
, useLabel(ST_v202)
,	/* CT_v204: (byte 0) */
  HW(0,0)
, 0
,	/* CF_LAMBDA188: (byte 0) */
  VAPTAG(useLabel(FN_LAMBDA188))
, bytes2word(1,0,0,1)
, useLabel(CT_v206)
,	/* FN_LAMBDA187: (byte 0) */
  useLabel(TMSUB_Prelude)
, bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,2)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 50042
, useLabel(ST_v205)
,	/* CT_v206: (byte 0) */
  HW(0,1)
, 0
,	/* F0_LAMBDA187: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA187),1)
, bytes2word(1,0,0,1)
, useLabel(CT_v208)
,	/* FN_LAMBDA186: (byte 0) */
  useLabel(TMSUB_Prelude)
, bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,1)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 50038
, useLabel(ST_v207)
,	/* CT_v208: (byte 0) */
  HW(0,1)
, 0
,	/* F0_LAMBDA186: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA186),1)
,	/* ST_v199: (byte 0) */
  bytes2word(80,114,101,108)
, bytes2word(117,100,101,46)
, bytes2word(115,112,97,110)
,	/* ST_v202: (byte 1) */
  bytes2word(0,80,114,101)
, bytes2word(108,117,100,101)
, bytes2word(46,115,112,97)
, bytes2word(110,58,52,58)
, bytes2word(49,45,54,58)
,	/* ST_v207: (byte 3) */
  bytes2word(52,48,0,80)
, bytes2word(114,101,108,117)
, bytes2word(100,101,46,115)
, bytes2word(112,97,110,58)
, bytes2word(53,58,51,56)
, bytes2word(45,53,58,51)
,	/* ST_v205: (byte 2) */
  bytes2word(57,0,80,114)
, bytes2word(101,108,117,100)
, bytes2word(101,46,115,112)
, bytes2word(97,110,58,53)
, bytes2word(58,52,50,45)
, bytes2word(53,58,52,51)
,	/* ST_v203: (byte 1) */
  bytes2word(0,80,114,101)
, bytes2word(108,117,100,101)
, bytes2word(58,46,47,83)
, bytes2word(112,97,110,46)
, bytes2word(104,115,58,32)
, bytes2word(80,97,116,116)
, bytes2word(101,114,110,32)
, bytes2word(109,97,116,99)
, bytes2word(104,32,102,97)
, bytes2word(105,108,117,114)
, bytes2word(101,32,105,110)
, bytes2word(32,102,117,110)
, bytes2word(99,116,105,111)
, bytes2word(110,32,97,116)
, bytes2word(32,52,58,49)
, bytes2word(45,54,58,52)
, bytes2word(48,46,0,0)
,};

==> nhc98src-1.20.tar.gz: nhc98-1.20/src/prelude/PreludeList/Span.z.c <==
#include "newmacros.h"
#include "runtime.h"

#define v198	((void*)startLabel+26)
#define v199	((void*)startLabel+37)
#define v200	((void*)startLabel+76)
#define v202	((void*)startLabel+93)
#define v195	((void*)startLabel+98)
#define CT_v206	((void*)startLabel+136)
#define FN_LAMBDA193	((void*)startLabel+180)
#define CT_v209	((void*)startLabel+212)
#define CF_LAMBDA193	((void*)startLabel+220)
#define FN_LAMBDA192	((void*)startLabel+232)
#define CT_v211	((void*)startLabel+256)
#define F0_LAMBDA192	((void*)startLabel+264)
#define FN_LAMBDA191	((void*)startLabel+276)
#define CT_v213	((void*)startLabel+300)
#define F0_LAMBDA191	((void*)startLabel+308)
#define ST_v204	((void*)startLabel+312)
#define ST_v207	((void*)startLabel+325)
#define ST_v212	((void*)startLabel+347)
#define ST_v210	((void*)startLabel+370)
#define ST_v208	((void*)startLabel+393)
extern Node TM_Prelude[];
extern Node CF_Prelude_46otherwise[];
extern Node FN_NHC_46Internal_46_95patternMatchFail[];
extern Node TMSUB_Prelude[];

static Node startLabel[] = {
  bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v206)
,};
Node FN_Prelude_46span[] = {
  useLabel(TM_Prelude)
, bytes2word(NEEDSTACK_I16,PUSH_ARG_I2,EVAL,NEEDHEAP_I32)
, bytes2word(TABLESWITCH,2,TOP(4),BOT(4))
,	/* v198: (byte 2) */
  bytes2word(TOP(15),BOT(15),POP_I1,HEAP_CVAL_IN3)
, bytes2word(HEAP_CVAL_IN3,PUSH_HEAP,HEAP_CVAL_N1,4)
, bytes2word(HEAP_OFF_N1,3,HEAP_OFF_N1,3)
,	/* v199: (byte 1) */
  bytes2word(RETURN,UNPACK,2,PUSH_P1)
, bytes2word(0,PUSH_ARG_I1,EVAL,NEEDHEAP_I32)
, bytes2word(APPLY,1,EVAL,NEEDHEAP_I32)
, bytes2word(JUMPFALSE,27,0,PUSH_HEAP)
, bytes2word(HEAP_CVAL_I3,HEAP_ARG,1,HEAP_I2)
, bytes2word(PUSH_HEAP,HEAP_CVAL_I4,HEAP_OFF_N1,4)
, bytes2word(PUSH_HEAP,HEAP_CVAL_I5,HEAP_OFF_N1,6)
, bytes2word(HEAP_CVAL_N1,5,HEAP_P1,3)
, bytes2word(HEAP_I1,PUSH_HEAP,HEAP_CVAL_N1,4)
,	/* v200: (byte 4) */
  bytes2word(HEAP_OFF_N1,4,HEAP_I1,RETURN)
, bytes2word(PUSH_CVAL_P1,6,ZAP_ARG_I1,EVAL)
, bytes2word(NEEDHEAP_I32,JUMPFALSE,11,0)
, bytes2word(HEAP_CVAL_IN3,PUSH_HEAP,HEAP_CVAL_N1,4)
, bytes2word(HEAP_OFF_N1,2,HEAP_ARG,2)
,	/* v202: (byte 1) */
  bytes2word(RETURN,POP_P1,2,JUMP)
,	/* v195: (byte 2) */
  bytes2word(2,0,HEAP_CVAL_P1,7)
, bytes2word(PUSH_HEAP,HEAP_CVAL_P1,8,HEAP_OFF_N1)
, bytes2word(2,RETURN_EVAL,ENDCODE,0)
, bytes2word(0,0,0,0)
, 0
, CONSTR(1,2,0)
, CONSTR(0,2,0)
, CONSTR(0,0,0)
, 40001
, useLabel(ST_v204)
,	/* CT_v206: (byte 0) */
  HW(6,2)
, 0
,};
Node F0_Prelude_46span[] = {
  CAPTAG(useLabel(FN_Prelude_46span),2)
, VAPTAG(useLabel(FN_Prelude_46span))
, VAPTAG(useLabel(FN_LAMBDA191))
, VAPTAG(useLabel(FN_LAMBDA192))
, useLabel(CF_Prelude_46otherwise)
, VAPTAG(useLabel(FN_LAMBDA193))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95patternMatchFail))
, bytes2word(0,0,0,0)
, useLabel(CT_v209)
,	/* FN_LAMBDA193: (byte 0) */
  useLabel(TMSUB_Prelude)
, bytes2word(NEEDHEAP_I32,PUSH_CADR_N1,4,STRING)
, bytes2word(RETURN,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, CONSTRW(1,0)
, useLabel(ST_v208)
, 40001
, useLabel(ST_v207)
,	/* CT_v209: (byte 0) */
  HW(0,0)
, 0
,	/* CF_LAMBDA193: (byte 0) */
  VAPTAG(useLabel(FN_LAMBDA193))
, bytes2word(1,0,0,1)
, useLabel(CT_v211)
,	/* FN_LAMBDA192: (byte 0) */
  useLabel(TMSUB_Prelude)
, bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,2)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 50042
, useLabel(ST_v210)
,	/* CT_v211: (byte 0) */
  HW(0,1)
, 0
,	/* F0_LAMBDA192: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA192),1)
, bytes2word(1,0,0,1)
, useLabel(CT_v213)
,	/* FN_LAMBDA191: (byte 0) */
  useLabel(TMSUB_Prelude)
, bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,1)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 50038
, useLabel(ST_v212)
,	/* CT_v213: (byte 0) */
  HW(0,1)
, 0
,	/* F0_LAMBDA191: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA191),1)
,	/* ST_v204: (byte 0) */
  bytes2word(80,114,101,108)
, bytes2word(117,100,101,46)
, bytes2word(115,112,97,110)
,	/* ST_v207: (byte 1) */
  bytes2word(0,80,114,101)
, bytes2word(108,117,100,101)
, bytes2word(46,115,112,97)
, bytes2word(110,58,52,58)
, bytes2word(49,45,54,58)
,	/* ST_v212: (byte 3) */
  bytes2word(52,48,0,80)
, bytes2word(114,101,108,117)
, bytes2word(100,101,46,115)
, bytes2word(112,97,110,58)
, bytes2word(53,58,51,56)
, bytes2word(45,53,58,51)
,	/* ST_v210: (byte 2) */
  bytes2word(57,0,80,114)
, bytes2word(101,108,117,100)
, bytes2word(101,46,115,112)
, bytes2word(97,110,58,53)
, bytes2word(58,52,50,45)
, bytes2word(53,58,52,51)
,	/* ST_v208: (byte 1) */
  bytes2word(0,80,114,101)
, bytes2word(108,117,100,101)
, bytes2word(58,46,47,83)
, bytes2word(112,97,110,46)
, bytes2word(104,115,58,32)
, bytes2word(80,97,116,116)
, bytes2word(101,114,110,32)
, bytes2word(109,97,116,99)
, bytes2word(104,32,102,97)
, bytes2word(105,108,117,114)
, bytes2word(101,32,105,110)
, bytes2word(32,102,117,110)
, bytes2word(99,116,105,111)
, bytes2word(110,32,97,116)
, bytes2word(32,52,58,49)
, bytes2word(45,54,58,52)
, bytes2word(48,46,0,0)
,};
